/**
* @FileName:	 EventManager.cpp
* @Programmer	 Brian Hinds
* @Date:         07-02-2017
* @Version:      1.0.2
*/
#include "EventManager.h"
#include "GameManager.h"

GameManager* EventManager::currentLevel;
bool EventManager::Loading;

/// <summary>
/// This method set the value of current level
/// </summary>
/// <method name= "Init"></method>
/// <param name="None"></param>
/// <returns>void</returns>
void EventManager::Init()
{
	Loading = true;
	currentLevel = 0;
}

/// <summary>
/// This method Initialize the current level
/// </summary>
/// <method name= "LoadInitialLevel"></method>
/// <param name="GameManager* Lvl"></param>
/// <returns>void</returns>
void EventManager::LoadInitialLevel(GameManager * Lvl)
{
	Loading = true;
	currentLevel = Lvl;
	currentLevel->Load();
	Loading = false;
}

/// <summary>
/// This method switches the current level to a new one
/// </summary>
/// <method name= "SwitchLevel"></method>
/// <param name="GameManager* Lvl"></param>
/// <returns>void</returns>
void EventManager::SwitchLevel(GameManager * Lvl)
{
	Loading = true;
	currentLevel->UnLoad();
	Lvl->Load();
	delete currentLevel;
	currentLevel = Lvl;
	Loading = false;
}

/// <summary>
/// This method render the graphics for the current level
/// </summary>
/// <method name= "Render"></method>
/// <param name="GameManager* EngineGFX"></param>
/// <returns>void</returns>
void EventManager::Rander()
{
	if (Loading) return;
	currentLevel->Render();
}

/// <summary>
/// This method updates the current level
/// </summary>
/// <method name= "Update"></method>
/// <param name="None"></param>
/// <returns>void</returns>
void EventManager::Update()
{
	if (Loading) return;
	currentLevel->Update();
}