/**
* @FileName:	 EventManager.h
* @Programmer	 Brian Hinds
* @Date:         07-02-2017
* @Version:      1.0.2
*/
#pragma once
#include "GameManager.h"

/// <summary>
/// Class Manages the different levels that the game may have.
/// It also manage how and when a level should load and the
/// switching of the levels.
/// </summary>
class EventManager
{
	EventManager() {}
	static GameManager* currentLevel;

public:
	/// <summary>
	/// This bool tell the game's loading state
	/// This prevents rendering while loading assets
	/// </summary>
	static bool Loading;

	/// <summary>
	/// Initialize values and assets for the level
	/// </summary>
	static void Init();

	/// <summary>
	/// Loads the level
	/// </summary>
	static void LoadInitialLevel(GameManager* Lvl);

	/// <summary>
	/// Switches level when current level is complete
	/// </summary>
	static void SwitchLevel(GameManager* Lvl);

	/// <summary>
	/// Renders the current level and any updates
	/// </summary>
	static void Rander();

	/// <summary>
	/// Updates any game behavior based on certain condition
	/// </summary>
	static void Update();
};