/**
* @FileName:	 Graphics.cpp
* @Programmer	 Brian Hinds
* @Date:         07-02-2017
* @Version:      1.0.2
*/
#include "Graphics.h"

/// <summary>
/// This method is a constructor that
/// Sets the graphics objects to NULL
/// </summary>
/// <method name= "Grapgics"></method>
/// <param name="None"></param>
/// <returns>None</returns>
Graphics::Graphics()
{
	EngineFactory = NULL;
	EngineRendertarget = NULL;
	brush = NULL;
}

/// <summary>
/// This method is a destructor for the graphics object
/// Freeing the memory when no longer needed
/// </summary>
/// <method name= "~Graphics"></method>
/// <param name="None"></param>
/// <returns>None</returns>
Graphics::~Graphics()
{
	if (EngineFactory) EngineFactory->Release();
	if (EngineRendertarget) EngineRendertarget->Release();
}

/// <summary>
/// This method Initialize the game window from the graphics
/// It also sets the render properties and objects needed for the graphics
/// </summary>
/// <method name= "Inti"></method>
/// <param name="HWND engineWindowHandle></param>
/// <returns>bool</returns>
bool Graphics::Inti(HWND engineWindowHandle)
{
	HRESULT engineResults = D2D1CreateFactory(D2D1_FACTORY_TYPE_MULTI_THREADED, &EngineFactory);
	if (engineResults != S_OK) return false;

	RECT GameEngineConsole;
	GetClientRect(engineWindowHandle, &GameEngineConsole);

	engineResults = EngineFactory->CreateHwndRenderTarget(
		D2D1::RenderTargetProperties(),
		D2D1::HwndRenderTargetProperties(engineWindowHandle,
			D2D1::SizeU(GameEngineConsole.right, GameEngineConsole.bottom)), &EngineRendertarget);

	if (engineResults != S_OK) return false;

	engineResults = EngineRendertarget->CreateSolidColorBrush(D2D1::ColorF(0, 0, 0, 0), &brush);

	if (engineResults != S_OK) return false;

	return true;
}

/// <summary>
/// This method clears the screen for each graphics
/// </summary>
/// <method name= "ClearScreen"></method>
/// <param name="float r,g,b"></param>
/// <returns>void</returns>
void Graphics::ClearScreen(float r, float g, float b)
{
	EngineRendertarget->Clear(D2D1::ColorF(r, g, b));
}

/// <summary>
/// Draws a circle with a define color and size
/// </summary>
void Graphics::DrawCircle(float x, float y, float radius, float r, float g, float b, float a)
{
	brush->SetColor(D2D1::ColorF(r, g, b, a));
	EngineRendertarget->DrawEllipse(D2D1::Ellipse(D2D1::Point2F(x, y), radius, radius), brush, 3.0f);
}