/**
* @FileName:	 Graphics.h
* @Programmer	 Brian Hinds
* @Date:         07-02-2017
* @Version:      1.0.2
*/
#pragma once
#include <Windows.h>
#include <d2d1.h>

/// <summary>
/// Class for Graphics
/// This class manages the Graphics objects
/// </summary>
class Graphics
{
	/// <summary>
	/// This factory allow many types of D2D resources to be created
	/// </summary>
	ID2D1Factory* EngineFactory;

	/// <summary>
	/// The render-target is similar to a back buffer from the GPU memory
	/// </summary>
	ID2D1HwndRenderTarget* EngineRendertarget;

	/// <summary>
	/// This is a COM interface that should also be release at the end
	/// </summary>
	ID2D1SolidColorBrush* brush;

public:
	/// <summary>
	/// This is the constructor for the graphics object
	/// </summary>
	Graphics();

	/// <summary>
	/// This is the destructor for the graphics objects
	/// </summary>
	~Graphics();

	/// <summary>
	/// This is initialize the game window
	/// </summary>
	bool Inti(HWND engineWindowHandle);

	/// <summary>
	/// This is allows the handing of bitmap image
	/// during the conversion process
	/// </summary>
	ID2D1RenderTarget* Rendertarget()
	{
		return EngineRendertarget;
	}

	/// <summary>
	/// This starts the drawing process
	/// </summary>
	void BeginDarw() { EngineRendertarget->BeginDraw(); }

	/// <summary>
	/// This ends the drawing process
	/// </summary>
	void EndDraw() { EngineRendertarget->EndDraw(); }

	/// <summary>
	/// This provides a clear screen
	/// </summary>
	void ClearScreen(float r, float g, float b);

	/// <summary>
	/// This draws a circle in the game window
	/// </summary>
	void DrawCircle(float c, float y, float radius, float r, float g, float b, float a);
};