/**
* @FileName:	 ImageManager.h
* @Programmer	 Brian Hinds
* @Date:         07-02-2017
* @Version:      1.0.2
*/
#pragma once
#include <wrl.h>
#include <wrl\client.h>
#include <d2d1effects_2.h>
#include <wincodec.h>
#include "resource.h"
#include "Graphics.h"

using Microsoft::WRL::ComPtr;

/// <summary>
/// Class for ImageManager
/// This class loads the image from file and
/// converts it to a ID2D1Bitmap image
/// It also manage chroma-key and composite images
/// </summary>
class ImageManager
{
	/// <summary>
	/// Setting up a graphic object
	/// </summary>
	Graphics* EngineGFX;

	ComPtr<ID2D1DeviceContext> m_d2dContext;

	/// <summary>
	/// This is a effect interface that should also be release at the end
	/// </summary>
	ComPtr<ID2D1Effect> chromakeyEffect;

	/// <summary>
	/// Instantiating bitmap object
	/// </summary>
	ID2D1Bitmap* GameBmpAsset;

	/// <summary>
	/// Variables for NPCs bitmap information
	/// </summary>
	int NPC_Width, NPC_Height;
	int NPC_Accross;

	/// <summary>
	/// Variables for chroma-key bitmap information
	/// </summary>
	int ChomaKeyImg_Width, ChomaKeyImg_Height;

public:
	/// <summary>
	/// Constructor that Gets the bitmap image from file
	/// </summary>
	ImageManager(wchar_t* filename, Graphics* EngineGFX);

	/// <summary>
	/// Constructor that Gets the NPC sprite bitmap image from file
	/// </summary>
	ImageManager(wchar_t* filename, Graphics* EngineGFX, int NPC_Width, int NPC_Height);

	/// <summary>
	/// Constructor that Gets the bitmap to chroma-key image from file
	/// </summary>
	ImageManager(wchar_t * filename, Graphics * EngineGFX, int ChromaValue);

	/// <summary>
	///Destructor that destroys bitmap object when no longer needed
	/// </summary>
	~ImageManager();

	/// <summary>
	/// Draws the bitmap
	/// </summary>
	void Draw(float x, float y);

	/// <summary>
	/// Draws the NPCs bitmap
	/// </summary>
	void DrawNPC(int index, float X_Position, float Y_Position);

	/// <summary>
	/// Draws the chroma-keyed bitmap
	/// </summary>
	void DrawChromaKeyedImage(float X_Position, float Y_Position);
};