/**
* @FileName:	 Sector01.cpp
* @Programmer	 Brian Hinds
* @Date:         07-02-2017
* @Version:      1.0.2
*/
#include "Sector01.h"
#include "Graphics.h"
#include "GameManager.h"

/// <summary>
/// This method Initialize the variables for current level
/// </summary>
/// <method name= "Load"></method>
/// <param name="GameManager* Lvl"></param>
/// <returns>void</returns>
void Sector01::Load()
{
	srand(time(NULL));

	/// <summary>
	/// Load NPC positions
	/// </summary>
	NPC_Y_Position = rand() % 619 + 77;
	NPC_X_Position = rand() % 824 + 100;
	NPCB_Y_Position = rand() % 619 + 77;
	NPCB_X_Position = rand() % 824 + 100;
	/// <summary>
	/// Load backgrounds
	/// </summary>
	StarShip_Y_Position = 77.0;
	StarShip_X_Position = 104.0;

	condition = rand() % 10 + 1;
	Splash = 0.0f;
	Sector = 0.0;
	frame = 0;
	hit = 0;
	StartGame = false;
	/// <summary>
	/// Load backgrounds
	/// </summary>
	BackgroundA = new ImageManager(L"SectorBackground.bmp", EngineGFX);
	BackgroundB = new ImageManager(L"Background01.png", EngineGFX);
	BackgroundC = new ImageManager(L"Background02.jpg", EngineGFX);
	BackgroundD = new ImageManager(L"Background03.jpg", EngineGFX);
	BackgroundE = new ImageManager(L"Background04.jpg", EngineGFX);
	BackgroundF = new ImageManager(L"Background05.jpg", EngineGFX);
	BackgroundG = new ImageManager(L"Background06.jpg", EngineGFX);
	Intro = new ImageManager(L"Splash.bmp", EngineGFX);
	/// <summary>
	/// GLoad planets
	/// </summary>
	PlanetA = new ImageManager(L"Planet1.bmp", EngineGFX);
	PlanetA = new ImageManager(L"Planet1.bmp", EngineGFX, 0);
	PlanetB = new ImageManager(L"Planet2.bmp", EngineGFX);
	PlanetC = new ImageManager(L"Planet3.bmp", EngineGFX);
	PlanetD = new ImageManager(L"Planet4.bmp", EngineGFX);
	PlanetE = new ImageManager(L"Planet5.bmp", EngineGFX);
	PlanetF = new ImageManager(L"Planet6.bmp", EngineGFX);
	PlanetG = new ImageManager(L"Planet7.bmp", EngineGFX);
	PlanetH = new ImageManager(L"Planet8.bmp", EngineGFX);
	PlanetI = new ImageManager(L"Planet9.bmp", EngineGFX);
	PlanetJ = new ImageManager(L"Planet10.bmp", EngineGFX);

	/// <summary>
	/// Load ship HUD
	/// </summary>
	ShipHudA = new ImageManager(L"S01.png", EngineGFX);
	ShipHudB = new ImageManager(L"S02.png", EngineGFX);
	ShipHudC = new ImageManager(L"S03.png", EngineGFX);
	ShipRadar = new ImageManager(L"radar.png", EngineGFX);
	/// <summary>
	/// Load ship damage stats
	/// </summary>
	ShipStat = new ImageManager(L"imagesHQBUG9TN.png", EngineGFX);
	DamageA = new ImageManager(L"Damage01.png ", EngineGFX);
	DamageB = new ImageManager(L"Damage02.png", EngineGFX);
	DamageC = new ImageManager(L"Damage03.png", EngineGFX);
	DamageD = new ImageManager(L"Damage04.png", EngineGFX);
	DamageE = new ImageManager(L"Damage05.png", EngineGFX);
	/// <summary>
	/// Load ship
	/// </summary>
	Ship = new ImageManager(L"ShipDetail.bmp", EngineGFX);
	/// <summary>
	/// Load NPCs
	/// </summary>
	NPC = new ImageManager(L"asteroid01.png", EngineGFX, 128, 128);
	NPCB = new ImageManager(L"rock.png", EngineGFX, 100, 100);
}

/// <summary>
///
/// </summary>
/// <method name= "Unload"></method>
/// <param name="None"></param>
/// <returns>void</returns>
void Sector01::UnLoad()
{
	delete BackgroundA;
	delete BackgroundB;
	delete BackgroundC;
	delete PlanetA;
	delete PlanetB;
	delete PlanetC;
	delete PlanetD;
	delete PlanetE;
	delete PlanetF;
	delete PlanetG;
	delete PlanetH;
	delete PlanetI;
	delete PlanetJ;
	delete ShipHudA;
	delete ShipHudB;
	delete ShipHudC;
	delete ShipStat;
	delete DamageA;
	delete DamageB;
	delete DamageC;
	delete DamageD;
	delete DamageE;
	delete Ship;
	delete NPC;
}

/// <summary>
/// This method updates the objects for the current level
/// </summary>
/// <method name= "Update"></method>
/// <param name="None"></param>
/// <returns>void</returns>
void Sector01::Update()
{
	Splash += 200;

	if (Splash > 767)
	{
		Splash = 777;
		/// <summary>
		/// Initial assets positions
		/// </summary>
		StarShip_X_Position += 1.0f;
		NPC_X_Position += 0.01f;
		NPC_Y_Position += 0.01f;

		if (StarShip_X_Position > 924)
		{
			StartGame = true;
			/// <summary>
			/// Random NPC positions
			/// </summary>
			NPC_Y_Position = rand() % 619 + 77;
			NPC_X_Position = rand() % 824 + 100;
			NPCB_Y_Position = rand() % 619 + 77;
			NPCB_X_Position = rand() % 824 + 100;
			condition = rand() % 15 + 1;
			/// <summary>
			/// Ship flight positions
			/// </summary>
			StarShip_X_Position = 128.0f;
			Sector += 1.0;

			if (Sector == 6)
			{
				Sector = 1;
			}
		}
		frame++;
	}
}

/// <summary>
/// This method renders the updated objects for the level
/// </summary>
/// <method name= "Render"></method>
/// <param name="GameManager* EngineGFX"></param>
/// <returns>void</returns>
void Sector01::Render()
{	/// <summary>
	/// Render splash screen
	/// </summary>
	if (Splash < 767)
	{
		Intro->Draw(0, 0);
	}

	if (StartGame)
	{
		Event01();
	}
}

/// <summary>
/// This method is the first event condition of the game
/// </summary>
/// <method name= "Event01"></method>
/// <param name="None"></param>
/// <returns>void</returns>
void Sector01::Event01()
{
	SectorBackground();
	Location();
	GameNPCs();
	Ship->Draw(StarShip_X_Position, StarShip_Y_Position);
	SetShipHuds();
}

/// <summary>
/// This method Assign location to the planets based on the random condition results
/// </summary>
/// <method name= "Location"></method>
/// <param name="None"></param>
/// <returns>void</returns>
void Sector01::Location()
{
	//							  [0]x [1]y    [0]x [1]y    [0]x [1]y    [0]x [1]y   [0]x [1]y    [0]x [1]y    [0]x [1]y     [0]x [1]y     [0]x [1]y
	int PlanetPoints[10][2] = { { 101, 77 },{ 204, 155 },{ 306, 232 },{ 410, 309 },{ 513, 386 },{ 615, 463 },{ 718, 540 },{ 820, 618 } ,{ 924, 696 } };
	//							  [0]           [1]          [2]         [3]           [4]         [5]			  [6]			[7]			[8]
	if (condition == 1)
	{
		PlanetAPositionX = PlanetPoints[7][0];
		PlanetAPositionY = PlanetPoints[0][1];
		PlanetBPositionX = PlanetPoints[4][0];
		PlanetBPositionY = PlanetPoints[5][1];
		PlanetCPositionX = PlanetPoints[1][0];
		PlanetCPositionY = PlanetPoints[6][1];

		PlanetD->Draw(PlanetAPositionX, PlanetAPositionY);
		PlanetE->Draw(PlanetBPositionX, PlanetBPositionY);
		PlanetF->Draw(PlanetCPositionX, PlanetCPositionY);
	}

	if (condition == 3)
	{
		PlanetAPositionX = PlanetPoints[2][0];
		PlanetAPositionY = PlanetPoints[4][1];
		PlanetBPositionX = PlanetPoints[4][0];
		PlanetBPositionY = PlanetPoints[0][1];
		PlanetCPositionX = PlanetPoints[6][0];
		PlanetCPositionY = PlanetPoints[3][0];

		//PlanetA->Draw(PlanetAPositionX, PlanetAPositionY);
		PlanetA->DrawChromaKeyedImage(PlanetAPositionX, PlanetAPositionY);
		PlanetB->Draw(PlanetBPositionX, PlanetBPositionY);
		PlanetC->Draw(PlanetCPositionX, PlanetCPositionY);
	}

	if (condition == 5)
	{
		PlanetAPositionX = PlanetPoints[2][0];
		PlanetAPositionY = PlanetPoints[1][1];
		PlanetBPositionX = PlanetPoints[2][0];
		PlanetBPositionY = PlanetPoints[5][1];
		PlanetCPositionX = PlanetPoints[5][0];
		PlanetCPositionY = PlanetPoints[3][1];

		PlanetG->Draw(PlanetAPositionX, PlanetAPositionY);
		PlanetH->Draw(PlanetBPositionX, PlanetBPositionY);
		PlanetI->Draw(PlanetCPositionX, PlanetCPositionY);
	}

	if (condition == 7)
	{
		PlanetAPositionX = PlanetPoints[0][0];
		PlanetAPositionY = PlanetPoints[5][1];
		PlanetBPositionX = PlanetPoints[4][0];
		PlanetBPositionY = PlanetPoints[0][1];
		PlanetCPositionX = PlanetPoints[2][0];
		PlanetCPositionY = PlanetPoints[2][1];

		PlanetD->Draw(PlanetAPositionX, PlanetAPositionY);
		PlanetE->Draw(PlanetBPositionX, PlanetBPositionY);
		PlanetF->Draw(PlanetCPositionX, PlanetCPositionY);
	}

	if (condition == 9)
	{
		PlanetAPositionX = PlanetPoints[3][0];
		PlanetAPositionY = PlanetPoints[0][1];
		PlanetBPositionX = PlanetPoints[2][0];
		PlanetBPositionY = PlanetPoints[3][1];

		//PlanetA->Draw(PlanetAPositionX, PlanetAPositionY);
		PlanetA->DrawChromaKeyedImage(PlanetAPositionX, PlanetAPositionY);
		PlanetB->Draw(PlanetBPositionX, PlanetBPositionY);
	}

	if (condition == 11)
	{
		PlanetAPositionX = PlanetPoints[5][0];
		PlanetAPositionY = PlanetPoints[2][0];

		PlanetG->Draw(PlanetAPositionX, PlanetAPositionY);
	}
}

/// <summary>
/// This method Assign different backgrounds
/// </summary>
/// <method name= "SectorBackground"></method>
/// <param name="None"></param>
/// <returns>void</returns>
void Sector01::SectorBackground()
{
	if (Sector == 1)
	{
		EngineGFX->ClearScreen(0.5f, 0.0f, 0.5f);
		BackgroundA->Draw(0.0, 0.0);
	}
	if (Sector == 2)
	{
		EngineGFX->ClearScreen(0.5f, 0.0f, 0.5f);
		BackgroundB->Draw(0.0, 0.0);
	}
	if (Sector == 3)
	{
		EngineGFX->ClearScreen(0.5f, 0.0f, 0.5f);
		BackgroundC->Draw(0.0, 0.0);
	}
	if (Sector == 4)
	{
		EngineGFX->ClearScreen(0.5f, 0.0f, 0.5f);
		BackgroundD->Draw(0.0, 0.0);
	}
	if (Sector == 5)
	{
		EngineGFX->ClearScreen(0.5f, 0.0f, 0.5f);
		BackgroundE->Draw(0.0, 0.0);
	}
	if (Sector == 6)
	{
		EngineGFX->ClearScreen(0.5f, 0.0f, 0.5f);
		BackgroundF->Draw(0.0, 0.0);
	}
	if (Sector == 6)
	{
		EngineGFX->ClearScreen(0.5f, 0.0f, 0.5f);
		BackgroundG->Draw(0.0, 0.0);
	}
}

/// <summary>
/// This method Assign different ship HUD
/// </summary>
/// <method name= "SetShipHuds"></method>
/// <param name="None"></param>
/// <returns>void</returns>
void Sector01::SetShipHuds()
{
	ShipStat->Draw(0.0, 0.0);
	ShipHudA->Draw(888.0, 0.0);
	ShipRadar->Draw(0.0, 672.0);
}

/// <summary>
/// This method Assign different game NPCs
/// </summary>
/// <method name= "GameNPCs"></method>
/// <param name="None"></param>
/// <returns>void</returns>
void Sector01::GameNPCs()
{
	if (condition == 1)
	{
		NPC->DrawNPC((frame / 60) % 4, NPC_X_Position, NPC_Y_Position);
	}
	if (condition == 2)
	{
		NPCB->DrawNPC((frame / 60) % 4, NPC_X_Position, NPC_Y_Position);
	}
}