/**
* @FileName:	 SetTrekEngine.cpp
* @Programmer	 Brian Hinds
* @Date:         07-02-2017
* @Version:      1.0.2
*/
#include "SetTrekPlugins.h"
#include "Graphics.h"
#include "Sector01.h"
#include "GameManager.h"
#include "EventManager.h"
#include "resource.h"

Graphics* GraphicsEngine;

/// <summary>
/// This method handles the system message, commends been passed
/// </summary>
/// <method name= "LRESULT CALLBACK WindowProc"></method>
/// <param name="HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lParam"></param>
/// <returns>hwnd, uMsg, wParam, lParam)</returns>
LRESULT CALLBACK WindowProc(HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lParam)
{
	if (uMsg == WM_DESTROY) { PostQuitMessage(0); return 0; }

	return DefWindowProc(hwnd, uMsg, wParam, lParam);
}

/// <summary>
/// This method is the main, it handles the game window, game loop and more
/// </summary>
/// <method name= "int WINAPI wWinMain"></method>
/// <param name="HINSTANCE hInstance, HINSTANCE prevInstance, LPWSTR cmd, int nCmdShow"></param>
/// <returns>int</returns>
int WINAPI wWinMain(HINSTANCE hInstance, HINSTANCE prevInstance, LPWSTR cmd, int nCmdShow)
{
	WNDCLASSEX engineClass;
	ZeroMemory(&engineClass, sizeof(WNDCLASSEX));
	engineClass.cbSize = sizeof(WNDCLASSEX);
	engineClass.hbrBackground = (HBRUSH)COLOR_WINDOW;
	engineClass.hIconSm = LoadIcon(NULL, (LPCSTR)IDI_ICON1);
	engineClass.hInstance = hInstance;
	engineClass.lpfnWndProc = WindowProc;
	engineClass.lpszClassName = "GameEngine";
	engineClass.style = CS_HREDRAW | CS_VREDRAW;

	RegisterClassEx(&engineClass);

	/// <summary>
	/// Setting game window play area
	/// </summary>
	RECT GameEngineConsole = { 0, 0, 1024, 768 };

	/// <summary>
	/// Allowing game window to be adjusted
	/// </summary>
	AdjustWindowRectEx(&GameEngineConsole, WS_OVERLAPPEDWINDOW, false, WS_EX_OVERLAPPEDWINDOW);

	/// <summary>
	/// Assigning the values and setting needed to launch the game window
	/// </summary>
	HWND engineWindowHandle = CreateWindowEx(WS_EX_OVERLAPPEDWINDOW, "GameEngine", "SET Trek Game", WS_OVERLAPPEDWINDOW,
		100, 100, GameEngineConsole.right - GameEngineConsole.left, GameEngineConsole.bottom - GameEngineConsole.top, NULL, NULL, hInstance, 0);

	/// <summary>
	/// Checking if game window initialization pass
	/// </summary>
	if (!engineWindowHandle) return -1;

	/// <summary>
	/// TInstanciating a new graphic object
	/// </summary>
	GraphicsEngine = new Graphics();

	/// <summary>
	/// Checking the graphic engine if it was initialized properly
	/// </summary>
	if (!GraphicsEngine->Inti(engineWindowHandle))
	{
		delete GraphicsEngine;
		return -1;
	}

	/// <summary>
	/// Initializing the graphic objects needed for the game
	/// </summary>
	GameManager::Init(GraphicsEngine);

	/// <summary>
	/// Showing the game window
	/// </summary>
	ShowWindow(engineWindowHandle, nCmdShow);

	/// <summary>
	/// Instantiating level one for game loop
	/// </summary>
	EventManager::LoadInitialLevel(new Sector01());

	/// <summary>
	/// Initializing message object for game loop
	/// </summary>
	MSG message;
	message.message = WM_NULL;

	/// <summary>
	/// This section is the game loop of main
	/// </summary>
	while (message.message != WM_QUIT)
	{
		if (PeekMessage(&message, NULL, 0, 0, PM_REMOVE))

			DispatchMessage(&message);

		else
		{
			EventManager::Update();

			GraphicsEngine->BeginDarw();

			EventManager::Rander();

			GraphicsEngine->EndDraw();
		}
	}
	/// <summary>
	/// Deletes the graphics objects releasing the used
	/// resources upon closing the game window
	/// </summary>
	delete GraphicsEngine;
	return 0;
}